Crate extxyz_types

Crate extxyz_types 

Structs

Boolean
A newtype wrapper around bool that dereferences to bool.
DictHandler
FloatNum
A newtype wrapper around f64 that dereferences to f64.
Frame
A raw frame parsed from an extxyz file.
Integer
A newtype wrapper around i32 that dereferences to i32.
Text
A newtype wrapper around String that dereferences to str.

Enums

Value
A dynamically-typed container for extended XYZ property values.

Functions

escape
checking special characters escape and escape as needed, using Cow because most string won’t need quoting.